import logging

from fastapi import APIRouter, Depends, Path

from id_broker_common.kelvin import kelvin_session
from self_disclosure_plugin.dependencies import (
    extract_members,
    get_connected_user,
    get_school_class,
    service_provider_from_token,
    token_dep,
)
from self_disclosure_plugin.models import ClassMembers, NoStarStr
from ucsschool.apis.opa import OPAClient, opa_instance
from ucsschool.apis.utils import get_logger
from ucsschool.kelvin.client import SchoolClass as KelvinSchoolClass, Session, User as KelvinUser

router = APIRouter(tags=["groups"], dependencies=[Depends(token_dep)])


@router.get("/{id}/users", response_model=ClassMembers)
async def group_users(
    school_class_pseudonym: NoStarStr = Path(
        ...,
        alias="id",
        description="Pseudonym of group for which to retrieve data.",
        title="Pseudonym",
    ),
    service_provider: str = Depends(service_provider_from_token),
    connected_user: KelvinUser = Depends(get_connected_user),
    policy_instance: OPAClient = Depends(opa_instance),
    session: Session = Depends(kelvin_session),
    logger: logging.Logger = Depends(get_logger),
) -> ClassMembers:
    school_class: KelvinSchoolClass = await get_school_class(
        school_class_pseudonym, service_provider, session
    )
    logger.debug(
        "school_class_pseudonym=%r service_provider=%r connected_user=%r school_class=%r",
        school_class_pseudonym,
        service_provider,
        connected_user,
        school_class,
    )
    await policy_instance.check_policy_true_or_raise(
        "self_disclosure_plugin/groups_members",
        {"user": connected_user.as_dict(), "group": school_class.as_dict()},
    )
    return await extract_members(school_class, service_provider)
